Module utils

Module utils 

Utilities.

Modules

webdriver
Keyboard related WebDriver functionality.

Functions

build_map
Build a map from a list of sequential codes.
load_data
Load the sequential codes from a plain text and returns it.