KeyInputState

Struct KeyInputState 

pub struct KeyInputState { /* private fields */ }
Store pressed keys and modifiers.

Spec: https://w3c.github.io/webdriver/#dfn-key-input-state

Implementations

Source

impl KeyInputState

pub fn new() -> KeyInputState

New state without any keys or modifiers pressed.

Same as the default value.

pub fn dispatch_keydown(&mut self, raw_key: char) -> KeyboardEvent

Get a keyboard-keydown event from a WebDriver key value.

Stores that the key is pressed in the state object.

The input cancel list is not implemented here but can be emulated by adding the raw_key value with a keyUp action to a list before executing this function.

Specification: https://w3c.github.io/webdriver/#dfn-dispatch-a-keydown-action

pub fn dispatch_keyup(&mut self, raw_key: char) -> Option<KeyboardEvent>

Get a keyboard-keyup event from a WebDriver key value.

Updates state. Returns None if the key is not listed as pressed.

Specification: https://w3c.github.io/webdriver/#dfn-dispatch-a-keyup-action